Module: Fluent::Plugin::RemoteSyslogOutput::SeverityMapper

Defined in:
lib/fluent/plugin/out_remote_syslog.rb

Overview

Convert some Severity values that is not supported in syslog_protocol library:

https://github.com/eric/syslog_protocol

We want to fix syslog_protocol itself, but it seems to be not maintained for a while. If the following PR is merged, we can remove this implementaion.

https://github.com/eric/syslog_protocol/pull/9

Constant Summary collapse

DICT =
{
  # "warning" is not supported, but we should use it since "warn" is deprecated.
  "warning" => "warn", 
}

Class Method Summary collapse

Class Method Details

.map(severity) ⇒ Object



167
168
169
# File 'lib/fluent/plugin/out_remote_syslog.rb', line 167

def self.map(severity)
  DICT[severity] || severity
end